@@ -5,11 +5,10 @@
 
 pub mod cross_compile;
 
-use cargo_metadata::MetadataCommand;
+use cargo_metadata::{MetadataCommand, Target};
 use libcnb_data::buildpack::SingleBuildpackDescriptor;
 use std::ffi::OsStr;
 use std::fs;
-use std::io;
 use std::path::{Path, PathBuf};
 use std::process::{Command, ExitStatus};
 
@@ -57,10 +56,16 @@ where
         .root_package()
         .ok_or(BuildError::CouldNotFindRootPackage)?;
 
-    let target = match buildpack_cargo_package.targets.as_slice() {
-        [] => Err(BuildError::NoTargetsFound),
+    let buildpack_bin_targets: Vec<&Target> = buildpack_cargo_package
+        .targets
+        .iter()
+        .filter(|target| target.kind == vec!["bin"])
+        .collect();
+
+    let target = match buildpack_bin_targets.as_slice() {
+        [] => Err(BuildError::NoBinTargetsFound),
         [single_target] => Ok(single_target),
-        _ => Err(BuildError::MultipleTargetsFound),
+        _ => Err(BuildError::MultipleBinTargetsFound),
     }?;
 
     let mut cargo_args = vec!["build", "--target", target_triple.as_ref()];
@@ -98,8 +103,8 @@ where
 pub enum BuildError {
     IoError(std::io::Error),
     UnexpectedExitStatus(ExitStatus),
-    NoTargetsFound,
-    MultipleTargetsFound,
+    NoBinTargetsFound,
+    MultipleBinTargetsFound,
     MetadataError(cargo_metadata::Error),
     CouldNotFindRootPackage,
 }
@@ -153,33 +158,26 @@ pub struct BuildpackData<BM> {
 ///
 /// # Errors
 ///
-/// Will return `Err` if the buildpack directory already exists or could not be assembled.
+/// Will return `Err` if the buildpack directory could not be assembled.
 pub fn assemble_buildpack_directory(
     destination_path: impl AsRef<Path>,
     buildpack_descriptor_path: impl AsRef<Path>,
     buildpack_binary_path: impl AsRef<Path>,
 ) -> std::io::Result<()> {
-    if destination_path.as_ref().exists() {
-        Err(io::Error::new(
-            io::ErrorKind::AlreadyExists,
-            "Destination path already exists!",
-        ))
-    } else {
-        fs::create_dir_all(destination_path.as_ref())?;
+    fs::create_dir_all(destination_path.as_ref())?;
 
-        fs::copy(
-            buildpack_descriptor_path.as_ref(),
-            destination_path.as_ref().join("buildpack.toml"),
-        )?;
+    fs::copy(
+        buildpack_descriptor_path.as_ref(),
+        destination_path.as_ref().join("buildpack.toml"),
+    )?;
 
-        let bin_path = destination_path.as_ref().join("bin");
-        fs::create_dir_all(&bin_path)?;
+    let bin_path = destination_path.as_ref().join("bin");
+    fs::create_dir_all(&bin_path)?;
 
-        fs::copy(buildpack_binary_path.as_ref(), bin_path.join("build"))?;
-        create_file_symlink("build", bin_path.join("detect"))?;
+    fs::copy(buildpack_binary_path.as_ref(), bin_path.join("build"))?;
+    create_file_symlink("build", bin_path.join("detect"))?;
 
-        Ok(())
-    }
+    Ok(())
 }
 
 #[cfg(target_family = "unix")]
